#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://www.scribus.net/canvas/Scribus
# last revised     : 11.06.2011

softname='scribus'
softversion='1.3.9'
packageversion='72.1'

arch='i686'
cpu='i686'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/project/scribus/scribus-devel/$softversion/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
scribus: scribus - Open-source Desktop Publishing
scribus:
scribus: Scribus is an open-source program that brings award-winning
scribus: professional page layout to Linux/Unix desktops with a combination
scribus: of 'press-ready' output and new approaches to page layout
scribus: 
scribus: 
scribus: 
scribus:
scribus:
scribus:
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    mkdir build
    cd build
    cmake .. \
	   -DCMAKE_INSTALL_PREFIX=/usr \
	   -DCMAKE_BUILD_TYPE=Release \
	   -DCMAKE_SKIP_RPATH=ON \
	   -DWANT_CAIRO=1 \
	   -DLIB_SUFFIX=""
	
    make || exit 1
    make install DESTDIR=$dest
    
# add 'default' files
mv $dest/usr/share/doc $dest/usr

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Make the package freedesktop compliant
mkdir $dest/usr/share/applications
cp $src/scribus.desktop $dest/usr/share/applications

mkdir -p $dest/usr/share/icons/hicolor/scalable/apps
cp $buildir/scribus.svg $dest/usr/share/icons/hicolor/scalable/apps

# Build
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# Compress Man Pages
mv $dest/$prefix/share/man $dest/$prefix/
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

#dep file
echo -e "aspell,cairo,cups,cxxlibs,gcc-g++,expat,fontconfig,freetype,gcc,glib2,lcms,\
libICE,libSM,libX11,libXau,libXdmcp,libXext,libXrender,libjpeg,libpng,libtiff,libxcb,\
libxml2,openssl,pixman,python,qt,util-linux,zlib" > $package.dep

# erase source
rm -rf $src
rm -rf $dest

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/scribus/source/build-scribus.sh > $package.src
echo $source >>$package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
